import { Container, GoogleReCaptcha } from '@google-recaptcha/core';
import { App, InjectionKey } from 'vue';
export interface GoogleReCaptchaState {
    googleReCaptcha?: GoogleReCaptcha.Instance;
    isLoading: boolean;
    language?: GoogleReCaptcha.Language;
    siteKey: string;
    executeV2Invisible: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => Promise<void>;
    executeV3: (action: GoogleReCaptcha.Action['action']) => Promise<string>;
    getResponse?: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => string;
    render?: (container: Container, parameters?: GoogleReCaptcha.Parameters, inherit?: boolean) => number;
    reset?: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => void;
}
export interface GoogleReCaptchaDefaultOptions {
    host?: GoogleReCaptcha.Host;
    isEnterprise?: boolean;
    language?: string;
    scriptProps?: GoogleReCaptcha.Script;
    siteKey: string;
    onError?: () => Promise<void>;
    onLoad?: (googleReCaptcha: GoogleReCaptcha.Instance) => Promise<void> | void;
}
export interface Explicit {
    container?: Container;
    inherit?: boolean;
    tabIndex?: number;
    callback?: (token: string) => void;
    errorCallback?: () => void;
    expiredCallback?: () => void;
}
export interface GoogleReCaptchaV2InvisibleOptions extends GoogleReCaptchaDefaultOptions {
    type: Extract<GoogleReCaptcha.Type, 'v2-invisible'>;
    explicit?: Explicit & {
        badge?: GoogleReCaptcha.Badge;
    };
}
export interface GoogleReCaptchaV2CheckBoxOptions extends GoogleReCaptchaDefaultOptions {
    type: Extract<GoogleReCaptcha.Type, 'v2-checkbox'>;
    explicit?: Explicit & {
        container: Container;
        action?: GoogleReCaptcha.Action['action'];
        theme?: GoogleReCaptcha.Theme;
        size?: GoogleReCaptcha.Size['v2-checkbox'];
    };
}
export interface GoogleReCaptchaV3Options extends GoogleReCaptchaDefaultOptions {
    type: Extract<GoogleReCaptcha.Type, 'v3'>;
    explicit?: Explicit & {
        badge?: GoogleReCaptcha.Badge;
    };
}
export type GoogleReCaptchaOptions = GoogleReCaptchaV2CheckBoxOptions | GoogleReCaptchaV2InvisibleOptions | GoogleReCaptchaV3Options;
export declare const RECAPTCHA_KEY: InjectionKey<Readonly<GoogleReCaptchaState>>;
export declare const GoogleReCaptchaPlugin: {
    install(app: App, options: GoogleReCaptchaOptions): void;
};
export default GoogleReCaptchaPlugin;
